% Script to summarize the offsets by individual cruises from a crossover analyses. 
% Create one plot per cruise with all the determined offsets.
% Remember to adjust your path to the data below.

% Toste Tanhua, Kiel, 2009.05.27

clear all; close all;
posfig(1);
mkdir('offsets');

% Make sure you have the right paths here
load crossover_add; %The additative crossovers
orginaladd=orginal; orgstdadd=orgstd;
load crossover_mult; %The multiplicative crossovers
orginal=orginal+1; 
UCR=unique([cr1 cr2]);

for hi=1:length(UCR), 
    %first load the data to get the expocode.
    cruises=UCR(hi); stations=1; load_carina; exp=expocode
    F=find(cr1 == UCR(hi));
    T=find(cr2 == UCR(hi));
       
    for j=1:4,
        add1=orginaladd(T,j)*(-1);
        std1=orgstdadd(T,j);
        add2=[orginaladd(F,j) ; add1];
        std2=[orgstdadd(F,j) ; std1];
        subplot(2,4,j),
        errorbar(add2,std2,'k.'); hold on
        set(gca,'xlim',[0 length(std2)]);
        grid on
        % Calculate and diplay the mean
        K=find(~isnan(add2));
        MM=mean(add2(K));
        plot(xlim,[MM MM],'r-');
        mm=sprintf('Mean = %1.3f',MM);
        if j==1,
            title('Salinity');
            set(gca,'ylim',[-70 70]);
            text(0,max(ylim)*9/10,mm);
        elseif j==2,
            title('TCO2');
            set(gca,'ylim',[-40 40]);
            text(0,max(ylim)*9/10,mm);
            text(0,min(ylim)*14/10,exp);
        elseif j==3.
            title('Alkalinity');
            set(gca,'ylim',[-40 40]);
            text(0,max(ylim)*9/10,mm);
        elseif j==4.
            title('pHsws25');
            set(gca,'ylim',[-0.05 0.05]);
            text(0,max(ylim)*9/10,mm);
            
        end
    end
    
    for j=1:4,
        mult1=1./orginal(T,j);
        std1=orgstd(T,j);
        mult2=[orginal(F,j) ; mult1];
        std2=[orgstd(F,j) ; std1];
        subplot(2,4,j+4),
        errorbar(mult2,std2,'k.'); hold on
        set(gca,'xlim',[0 length(std2)]);
        grid on
        % Calculate and diplay the mean
        K=find(~isnan(mult2));
        MM=mean(mult2(K));
        plot(xlim,[MM MM],'r-');
        mm=sprintf('Mean = %1.3f',MM);
        if j==1,
            title('Nitrate');
            set(gca,'ylim',[0.5 1.5]);
            text(0,1.4,mm);
        elseif j==2,
            title('Phosphate');
            set(gca,'ylim',[0.5 1.5]);
            text(0,1.4,mm);
        elseif j==3,
            title('Silicate');
            set(gca,'ylim',[0.5 1.5]);
            text(0,1.4,mm);
        elseif j==4,
            title('Oxygen');
            set(gca,'ylim',[0.8 1.2]);
            text(0,1.17,mm);
        end
    end
    
    orient portrait
    plotname=cat(2,'offsets','\',exp{1},'___offsets');
    eval(['print -dpng -r300  ' plotname]);
    pause(1)
    clf
        
end

    