% Function to find crossovers for a set of cruises.
% A txt file will be saved that can be used later for looping through all
% the crossovers
% 
% Toste Tanhua 2009.06.05

clear all; close all;

% Load the desired merged CARINA data file
load CARINA_ATL

for i=1:length(hdr0);
     carinavar=[hdr0{i}, ' = data(:,i);'];
     eval(carinavar);
end

% This is to reduce the number of crossovers by removing all shallow stations
t=unique(cruiseno); latlim=2; mindepth=1500; 

inform=[]; expoc=[];
for m=1:length(t)-1, 
            % Load the data for the first cruise
            cruises=t(m); stations=-999; load_carina; expocode
            D=find(depth >= mindepth); latitude=latitude(D); longitude=longitude(D); station=station(D); year=year(D);
            [statnum1,I,J] = unique(station); lon1=longitude(I); lat1=latitude(I); year1=year(I); C1=expocode;
            if isempty(lon1),
                disp('No deep stations for cruise1');
                continue
            end

        for j=m+1:length(t),
            % Load the data for the second cruise
            cruises=t(j); stations=-999; load_carina; expocode
            D=find(depth >= mindepth); latitude=latitude(D); longitude=longitude(D); station=station(D); year=year(D);
            [statnum2,I,J] = unique(station); lon2=longitude(I); lat2=latitude(I); year2=year(I); C2=expocode;
            if isempty(lon2),
                disp('No deep stations for cruise2');
                continue
            end             

            % Find all stations in cruise 2 that are within the lat range of cruise1
            K=find(lat2>min(lat1)-latlim & lat2<max(lat1)+latlim);
            lat2=lat2(K); lon2=lon2(K); statnum2=statnum2(K);
            
            % Find any stations on the second cruise that are within the limits of xover
            stat2=[];
            for k=1:length(lat1);
                F=find(lat2<lat1(k)+latlim & lat2>lat1(k)-latlim); ST=statnum2(F);
                % calculate the distance in lon
                lonlim=latlim / cos(lat1(k)/180*pi);
                G=find(lon2(F)<lon1(k)+lonlim & lon2(F)>lon1(k)-lonlim);
                st2=ST(G);
                stat2=[stat2;st2];
            end
%            % 
            W=[];
            for k=1:length(stat2),
              J=find(statnum2==stat2(k));
              W=[W ; J(:)];
            end
            lonx2=lon2(W); latx2=lat2(W); STAT2=statnum2(W);
            [STAT2,I,J]=unique(stat2);latx2=latx2(I); lonx2=lonx2(I);
            sizeC2=length(STAT2);

            %---------------------------------------
            % Find any stations on the first cruise that are within the limits of xover
            stat1=[];
            for k=1:length(latx2);
                F=find(lat1<latx2(k)+latlim & lat1>latx2(k)-latlim); ST=statnum1(F);
                % calculate the distance in lon
                lonlim=latlim / cos(latx2(k)/180*pi);
                G=find(lon1(F)<lonx2(k)+lonlim & lon1(F)>lonx2(k)-lonlim); st1=ST(G);
                stat1=[stat1;st1];
            end

            % 
            W=[];
            for k=1:length(stat1),
              J=find(statnum1==stat1(k));
              W=[W ; J(:)];
            end
            lonx1=lon1(W); latx1=lat1(W); STAT1=statnum1(W);
            [STAT1,I,J] = unique(STAT1); lonx1=lonx1(I); latx1=latx1(I);
            STAT1;
            sizeC1=length(STAT1);
%                         
            % Note the difference in years;
            y1=unique(year1); y2=unique(year2);
            if length(y1)>2 & length(y2)>2,
                delyear=y2-y1;
            else
                delyear=1000; % For time series
            end

            mlon=mean(unique(lonx1));
            mlat=mean(unique(latx1));
                       
            if sizeC1 ~= 0,
                inf=[t(m) t(j) sizeC1 sizeC2 delyear mlat mlon]
                inform=[inform;inf];
                exp=[C1 C2]
                expoc=[expoc;exp];
            end
                       
        end
 end

% Write a txt file with the numberic data
fname=sprintf('xoverinfo.txt');
fid=fopen(fname,'w');
fprintf(fid,'%f %f %f %f %f %f %f\n',[inform]');
fclose(fid);

% Write a txt file with the EXPOCODE data
fid = fopen('expoinfo.txt','w'); 
for (k=1:length(expoc))
     fprintf(fid,'%s %s\n',char(expoc(k,1)),char(expoc(k,2)));
end 
fclose(fid);  

