% Script that loops through a defined set of crossovers and automatically
% preforms the crossovers.
% It also saves a txt file with the data and two mat-files (one for the
% multiplicative and one for the additative) for later use in inversions. 
% You might want to change the names of these outputfiles. 
%
% Toste Tanhua  2009.06.05

clear all; close all;
load xoverinfo.txt;  DAT=xoverinfo;

cru1=DAT(:,1); cru2=DAT(:,2);
RESULT=[];
save stacked RESULT
for j=1:8, 
    for k=1:length(cru1),
        %[diff, stdw] = xover(cruise1,cruise2,parameter)
        [diff, stdw] = xover_RC(cru1(k),cru2(k),j);
        RE=[diff stdw]
        Xover_no=k
        % This is all too avoid to have too many files open
        save temporary RE
        fclose all
        load temporary
        load stacked
        RESULT=[RESULT ; RE];
        save stacked RESULT
        %pause
    end
    ss=sprintf('RESULT_%d  RESULT',j)
    eval(['save  ' ss]);
    RESULT=[];
    save stacked RESULT
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This part of the script produces a txt-table with the Xover information from one of the
% automated runs.

clear all; close all;
load RESULT_1; tco2=RESULT;
load RESULT_2; alk=RESULT;
load RESULT_3; oxygen=RESULT;
load RESULT_4; nitrate=RESULT;
load RESULT_5; phosphate=RESULT;
load RESULT_6; silicate=RESULT;
load RESULT_7; sal=RESULT;
load RESULT_8; phsws25=RESULT;

load xoverinfo.txt
data=xoverinfo;
cr1=data(:,1);   cr2=data(:,2);
nost1=data(:,3); nost2=data(:,4);
dely=data(:,5);  lat=data(:,6);   lon=data(:,7); 
DD=[ dely lat lon cr1 cr2 sal tco2 alk nitrate phosphate silicate oxygen]';
% Write to file
fname=sprintf('crossover_results.txt');
fid=fopen(fname,'w');
fprintf(fid,'%f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f\n',DD);
fclose(fid);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This part of the script produces matlab files for the inversion
% Make sure you load the correct weights here
load weights.txt  

dely=abs(dely); DD(DD==-999)=NaN;
[cr1,I]=sort(cr1); % Sort all the data
cr2=cr2(I); dely=dely(I); lat=lat(I); lon=lon(I);
sal=sal*1000;  % Do salinity in ppm

% For Additative
variables={ 'sal' , 'tco2' , 'alk' , 'phsws25'};
orginal=[sal(:,1) tco2(:,1) alk(:,1) phsws25(:,1)]; orginal=orginal(I,:); % These are the original offsets
orgstd=[sal(:,2) tco2(:,2) alk(:,2) phsws25(:,2)];  orgstd=orgstd(I,:);   % These are the origianal std devs
vikter=weights(:,1:5);
save crossover_add dely lon lat cr1 cr2 vikter orginal orgstd variables

% For Multiplicative
variables={ 'nitrate' , 'phosphate' , 'silicate' , 'oxygen'};
orginal=[nitrate(:,1) phosphate(:,1) silicate(:,1) oxygen(:,1)]; orginal=orginal(I,:); % These are the original offsets
% The multiplicative corrections has to be subtracted from unity
orginal=orginal-1;
orgstd=[nitrate(:,2) phosphate(:,2) silicate(:,2) oxygen(:,2)];  orgstd=orgstd(I,:);   % These are the origianal std devs
vikter=weights(:,[1 6:9]);
save crossover_mult dely lon lat cr1 cr2 vikter orginal orgstd variables

% To plot the offsets for all cruises
offsetplot

