function [STAT1,STAT2]=xovermap(latlim,mindepth)
%
% Function to make a map of two cruises and mark stations that are selected for
% crossover analysis
% 
% INPUT:  cruise1 = The first cruise
%         cruise2 = The second cruise
%         latlim = The maximum distance between two cruises to define a X-over (in deg lat)
%                  
% OUTPUT: STAT1 = xover stations for the first cruise
%         STAT2 = xover stations for the second cruise
%         
% Toste Tanhua  2009.06.05


global stat1 press1 dens1 param1 lon1 lat1 depth1 stat1 stat2 lat2 lon2 depth2 dens2 param2 expo1 expo2

STAT1=[];STAT2=[];
lonmin=min([lon1;lon2])-5; lonmax=max([lon1;lon2])+5; latmax=max([lat1;lat2])+latlim; latmin=min([lat1;lat2])-latlim;

% CHANGE HERE FOR ANOTHER VIEW OF THE MAP
LATMAX= latmax+10; LATMIN=latmin-10; LONMIN=lonmin-10; LONMAX=lonmax+10; 

posfig(1);
% position      [left bottom width height]
htop=axes('position',[.1 .7 .4 .27]); 
%htop=axes('position',[.1 .3 .7 .5]);
m_proj('Mercator','long',[LONMIN,LONMAX],'lat',[LATMIN,LATMAX]);
m_coast('patch','k'); hold on
m_tbase('contour',[-1000 -2000 -3000 -4000]); % activating this produces
% bottom contours, but takes plenty computer power
m_grid('box','fancy');

% Plot the cruises
[x,y]=m_ll2xy(lon1,lat1); plot(x,y,'.b','markersize',14); hold on
[x,y]=m_ll2xy(lon2,lat2); plot(x,y,'xr','markersize',8);


% Find any stations on the second cruise that are within the limits of xover
for i=1:length(lat1);
    % calculate the distance in lon
    lonlim=latlim / cos(lat1(i)/180*pi);
    for j=1:length(lat2),
            if(lat2(j)<lat1(i)+latlim & lat2(j)>lat1(i)-latlim & lon2(j)<lon1(i)+lonlim & lon2(j)>lon1(i)-lonlim),
                st2=stat2(j); STAT2=[STAT2;st2];
                st1=stat1(i); STAT1=[STAT1;st1];
            end
    end    
end
STAT2=unique(STAT2);
STAT1=unique(STAT1);

return
